diff sipr.c @ 11462:c2e19a511e26 libavcodec

Fix spelling.
author rbultje
date Thu, 11 Mar 2010 17:42:53 +0000
parents ff7c1c90b6f5
children 8a4984c5cacc
line wrap: on
line diff
--- a/sipr.c	Thu Mar 11 10:52:34 2010 +0000
+++ b/sipr.c	Thu Mar 11 17:42:53 2010 +0000
@@ -254,7 +254,7 @@
 }
 
 /**
  * Evaluates the adaptative impulse response.
  */
 static void eval_ir(const float *Az, int pitch_lag, float *freq,
                     float pitch_sharp_factor)
@@ -479,8 +479,8 @@
             float energy = ff_dot_productf(ctx->postfilter_syn5k0 + LP_FILTER_ORDER + i*SUBFR_SIZE,
                                            ctx->postfilter_syn5k0 + LP_FILTER_ORDER + i*SUBFR_SIZE,
                                            SUBFR_SIZE);
-            ff_adaptative_gain_control(&synth[i * SUBFR_SIZE], energy,
-                                       SUBFR_SIZE, 0.9, &ctx->postfilter_agc);
+            ff_adaptive_gain_control(&synth[i * SUBFR_SIZE], energy,
+                                     SUBFR_SIZE, 0.9, &ctx->postfilter_agc);
         }
 
         memcpy(ctx->postfilter_syn5k0, ctx->postfilter_syn5k0 + frame_size,
@@ -254,7 +254,7 @@
 
 /**
- * Evaluates the adaptative impulse response.
+ * Evaluates the adaptive impulse response.
  */
 static void eval_ir(const float *Az, int pitch_lag, float *freq,